mf2 package
===========

Fixed Functions
---------------
.. toctree::

   functions/multiFidelityFunction
   functions/bohachevsky
   functions/booth
   functions/borehole
   functions/branin
   functions/currin
   functions/forrester
   functions/hartmann
   functions/himmelblau
   functions/park91a
   functions/park91b
   functions/six_hump_camelback


Adjustable Functions
--------------------
.. toctree::

   functions/adjustable/branin
   functions/adjustable/paciorek
   functions/adjustable/hartmann
   functions/adjustable/trid
